import fs from "fs/promises";
import path from "path";
import matter from "gray-matter";
import { remark } from "remark";
import html from "remark-html";

// common function for get all post data
async function getAllPosts(fileDirectory) {
  const directory = path.join(process.cwd(), fileDirectory);
  const fileNames = await fs.readdir(directory);
  const post = await Promise.all(
    fileNames.map(async (fileName) => {
      const id = fileName.replace(/\.md$/, "");
      const fullPath = path.join(fileDirectory, fileName);
      const fileContents = await fs.readFile(fullPath, "utf8");
      const { data, content } = matter(fileContents);
      const processedContent = remark()
        .use(html)
        .processSync(content)
        .toString();
      return {
        id,
        ...data,
        markdown: processedContent,
      };
    })
  );
  return post;
}

function getSlicedPost(post, page) {
  const itemsPerPage = 6;
  // Calculate the start and end indices for the current page
  const startIndex = (page - 1) * itemsPerPage;
  const endIndex = startIndex + itemsPerPage;
  const slicedData = Array.isArray(post)
    ? post.slice(startIndex, endIndex)
    : [];
  const totalPages = Math.ceil(post?.length / itemsPerPage);
  const response = { blogs: slicedData, total: totalPages };
  return response;
}

//common function end

//get by slug
export async function getPostBySlug(slug) {
  const blogs = await getAllPosts("posts");
  return blogs.filter((e) => e.slug === slug)[0];
}

//get all
export async function getPosts(fileDirectory, page) {
  let post = await getAllPosts(fileDirectory, page);
  return getSlicedPost(post, page);
}

//get by search
export async function getPostsBySearch(fileDirectory, page, search) {
  const post = await getAllPosts(fileDirectory);
  const filterBlog = post.filter((e) => {
    return e.title.toLowerCase().includes(search.toLowerCase());
  });
  let pageNo = filterBlog.length > 6 ? page : page == 1 ? 1 : 0;
  const slicedPost = getSlicedPost(filterBlog, pageNo);
  return slicedPost;
}
